==> qtsmbstatus_2.0.3.orig.tar.gz: qtsmbstatus-2.0.3/server/server.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Daniel Rocher                                   *
 *   daniel.rocher@adella.org                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************/

#ifndef SERVER_H
#define SERVER_H

#include <Q3ServerSocket>

#include "clientsocket.h"

extern SSL_CTX* ssl_ctx;

class Server : public Q3ServerSocket
{
    Q_OBJECT
public:
	Server( QObject* parent=0 );
	virtual ~Server();
	void newConnection( int socket );
public slots:
	void stopserver();
};

#endif

==> qtsmbstatus_2.2.1.orig.tar.gz: qtsmbstatus-2.2.1/server/server.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Daniel Rocher                                   *
 *   daniel.rocher@adella.org                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************/

#ifndef SERVER_H
#define SERVER_H

#include <QTcpServer>
#include <QSslCertificate>
#include <QSslKey>
#include "clientsocket.h"

class Server : public QTcpServer
{
    Q_OBJECT
public:
	Server(const QString & certificatFile, const QString & privateKeyFile ,const QString & sslPassword , QObject* parent=0 );
	virtual ~Server();
	void incomingConnection( int socket );
	static int compteur_objet;
public slots:
	void stopServer();
private:
	QSslCertificate certif;
	QSslKey s_key;
};

#endif
